@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/xmonad-0.11/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: xmonad
-version: 0.10
-id: xmonad-0.10-9098873644798ba05a3da4f132de9a0a
+version: 0.11
+id: xmonad-0.11-8895dc78765dd76adca07ddb4db14c91
 
 license: BSD3
 copyright:
@@ -9,6 +10,7 @@ maintainer: xmonad@haskell.org
 stability:
 homepage: http://xmonad.org
 package-url:
+synopsis: A tiling window manager
 description: xmonad is a tiling window manager for X. Windows are arranged
              automatically to tile the screen without gaps or overlap, maximising
              screen use. All features of the window manager are accessible from
@@ -25,28 +27,29 @@ exposed: True
 exposed-modules: XMonad XMonad.Main XMonad.Core XMonad.Config
                  XMonad.Layout XMonad.ManageHook XMonad.Operations XMonad.StackSet
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/xmonad-0.10
-library-dirs: /usr/local/lib/ghc/xmonad-0.10
-hs-libraries: HSxmonad-0.10
+trusted: False
+import-dirs: /usr/local/lib/ghc/xmonad-0.11
+library-dirs: /usr/local/lib/ghc/xmonad-0.11
+hs-libraries: HSxmonad-0.11
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: X11-1.6.0-34d5fa7e6b479ed438484c2315a89d50
-         base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
-         directory-1.1.0.0-0764d4838863123df574e64d163bd619
-         extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
-         filepath-1.2.0.0-b4f4cf7e95546b00f075372f0ccb0653
-         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
-         process-1.0.1.5-da4848a2eec47420cd09fe9edba7e83c
-         unix-2.4.2.0-ede8c1b2fd228f3f436412134498aafc
-         utf8-string-0.3.6-213e09c7f4f705610e4e35b79f03acb5
+depends: X11-1.6.1.1-3a65c01bb60e27391be7fb564fa7621e
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         directory-1.2.1.0-255ee2a4a618c74613f025ccc4ecc082
+         extensible-exceptions-0.1.1.4-ff00541964e8b4f6fe7adae94cd5f3b4
+         filepath-1.3.0.2-25a474a9272ae6260626ce0d70ad1cab
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         process-1.2.0.0-891670ec11c8b086a673596aa083f351
+         unix-2.7.0.1-49291e6beb52ca8844af5af8283d8383
+         utf8-string-0.3.8-33d6cbdc649f1dd0048718c4b65b149b
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-xmonad-0.10/html/xmonad.haddock
-haddock-html: /usr/local/share/doc/hs-xmonad-0.10/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-xmonad-0.11/html/xmonad.haddock
+haddock-html: /usr/local/share/doc/hs-xmonad-0.11/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
